@@ -8,7 +8,7 @@ from hpogrid.configuration.grid_configuration import GridConfiguration
 from hpogrid.configuration.search_space_configuration import SearchSpaceConfiguration
 from hpogrid.configuration.project_configuration import ProjectConfiguration
 from hpogrid.configuration.model_configuration import ModelConfiguration
-from hpogrid.components.panda_task_manager import PandaTaskManager
+#from hpogrid.components.panda_task_manager import PandaTaskManager
 from hpogrid.utils.helper import get_workdir, load_configuration
 from hpogrid.components.environment_settings import *
 from hpogrid.components.core import *
\ No newline at end of file
